@@ -142,9 +142,9 @@ def get_members_from_file(file_path: str, name="module"):
         spec.loader.exec_module(module)
         members = inspect.getmembers(module, lambda member: not inspect.ismodule(member))
         members_list = []
-        for name, value in members:
-            if not name.startswith('_'):
-                info = {"name": name, "value": value}
+        for key, value in members:
+            if not key.startswith('_'):
+                info = {"name": key, "value": value}
                 if inspect.isclass(value):
                     info["type"] = "class"
                     class_members = []
